/*
 * Copyright (C) 2000 Free Software Foundation, Inc.
 * Brian Satterfield <legowhore@legowhore.com>, 2000.
 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package com.legowhore.q3;

import javax.swing.BorderFactory; 
import javax.swing.border.Border;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JButton;
import javax.swing.JPanel;
import java.awt.Color;
import java.util.Vector;
import javax.swing.ImageIcon;
import javax.swing.SwingUtilities;

public class ButtonPanel extends JPanel implements Runnable {
    
    //  action buttons
    private JButton ipButton;
    private JButton viewButton;
    private JButton passwordButton;
    private JButton portButton;
    private JButton infoButton;
    private JButton aboutButton;
    private JButton mapsButton;
    private JButton settingsButton;
    private JButton statisticsButton;
    private JButton botsButton;
    private JButton startButton;
    private JButton chatButton;

    //  different panels
    private JPanel panelA;
    private JPanel panelB;
    private JPanel panelC;
    private JPanel panelD;
    private JPanel panelE;
    
    //  parent
    Q3ServerKit q3Gui;

    //  used to hold all the panels
    Vector panels;

    //  used as a placeholder to remember 
    //  the current panel...for switching later
    int currentPanel = 1;
    int nextPanel = 1;

    //  navigation button
    JButton nextButton;

    public ButtonPanel(Q3ServerKit q3Gui) {
	this.q3Gui = q3Gui;
 	Border etched = BorderFactory.createEtchedBorder();
 	setBorder(etched);
	setLayout(new PercentLayout());
	setBackground(Color.black);

	//  create the buttons
	ipButton = new JButton("host");
	ipButton.setForeground(Color.green);
	ipButton.setBackground(Color.black);
	ipButton.addActionListener(new ActionButtonListener());
	viewButton = new JButton("list");
	viewButton.setForeground(Color.yellow);
	viewButton.setBackground(Color.black);
	viewButton.addActionListener(new ActionButtonListener());
	passwordButton = new JButton("pass");
	passwordButton.setForeground(Color.red);
	passwordButton.setBackground(Color.black);
	passwordButton.addActionListener(new ActionButtonListener());
	portButton = new JButton("port");
	portButton.setForeground(Color.blue);
	portButton.setBackground(Color.black);
	portButton.addActionListener(new ActionButtonListener());
	infoButton = new JButton("info");
	infoButton.setForeground(Color.white);
	infoButton.setBackground(Color.black);
	infoButton.addActionListener(new ActionButtonListener());
	aboutButton = new JButton("about");
	aboutButton.setForeground(Color.magenta);
	aboutButton.setBackground(Color.black);
	aboutButton.addActionListener(new ActionButtonListener());
	mapsButton = new JButton("maps");
	mapsButton.setForeground(Color.orange);
	mapsButton.setBackground(Color.black);
	mapsButton.addActionListener(new ActionButtonListener());
	settingsButton = new JButton("vars");
	settingsButton.setForeground(Color.cyan);
	settingsButton.setBackground(Color.black);
	settingsButton.addActionListener(new ActionButtonListener());
	statisticsButton = new JButton("stats");
	statisticsButton.setForeground(Color.pink);
	statisticsButton.setBackground(Color.black);
	statisticsButton.addActionListener(new ActionButtonListener());
	botsButton = new JButton("bots");
	botsButton.setForeground(Color.red);
	botsButton.setBackground(Color.black);
	botsButton.addActionListener(new ActionButtonListener());
	startButton = new JButton("start");
	startButton.setForeground(Color.lightGray);
	startButton.setBackground(Color.black);
	startButton.addActionListener(new ActionButtonListener());
	chatButton = new JButton("chat");
	chatButton.setForeground(Color.gray);
	chatButton.setBackground(Color.black);
	chatButton.addActionListener(new ActionButtonListener());
	
	//  group the buttons
	Vector buttonsA = new Vector();
	buttonsA.addElement(ipButton);
	buttonsA.addElement(passwordButton);
	buttonsA.addElement(portButton);
	buttonsA.addElement(startButton);
	buttonsA.addElement(aboutButton);

	Vector buttonsB = new Vector();
	buttonsB.addElement(viewButton);
	buttonsB.addElement(infoButton);
	buttonsB.addElement(botsButton);
	buttonsB.addElement(chatButton);
	
	Vector buttonsC = new Vector();
	buttonsC.addElement(mapsButton);
	buttonsC.addElement(settingsButton);
	buttonsC.addElement(statisticsButton);
	
	Vector buttonsD = new Vector();
	Vector buttonsE = new Vector();

	//  create the different panels
	panelA = new JPanel();
	panelB = new JPanel();
	panelC = new JPanel();
	panelD = new JPanel();
	panelE = new JPanel();
	
	//  holds all the panels 
	panels = new Vector();

	//  assemble the panels
	assemblePanel(buttonsB, panelB);
	assemblePanel(buttonsA, panelA);
	assemblePanel(buttonsC, panelC);
	assemblePanel(buttonsD, panelD);
	assemblePanel(buttonsE, panelE);

	//  navigation buttons
	nextButton = new JButton("next");
	nextButton.setBackground(Color.black);
	nextButton.setForeground(Color.white);
	nextButton.addActionListener(new NextButtonListener());

	//  add components
	add((JPanel) panels.elementAt(currentPanel), "0 0 100 83");
	add(nextButton, "10 85 90 98");
    }

    //  used to assemble an arbitrary panel and a set of buttons
    private void assemblePanel(Vector buttons, JPanel panel) {
	int size = buttons.size();
	if(size < 1) 
	    return;
	panel.setLayout(new PercentLayout());
	panel.setBackground(Color.black);
	int top = 5;
	int bottom = 22;
	for(int i = 0; i < size; i++) {
	    String layout = ("5 " + top + " 95 " + bottom);
	    panel.add((JButton) buttons.elementAt(i), layout);
	    top = bottom + 2;
	    bottom = top + 17;
	}
	panels.addElement(panel);
    }

    //  used to change the button display...
    //  run in the event dispatch thread
    public void run() {
	this.invalidate();
	remove((JPanel) panels.elementAt(currentPanel));
	add((JPanel) panels.elementAt(nextPanel), "0 0 100 83");
	currentPanel = nextPanel;
	this.repaint();
	this.validate();
    }

    //  determines all functions of the action buttons
    class ActionButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    JButton button = (JButton) e.getSource();
	    String title = button.getText();
	    q3Gui.newAction(title);
	}
    }

    //  listens for a shift left request
    class NextButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    JButton pressed = (JButton) e.getSource();
	    ButtonPanel thisPanel = (ButtonPanel) pressed.getParent();
	    if(nextPanel == (panels.size() - 1)) 
		nextPanel = 0;
	    else 
		nextPanel++;
	    try {
		SwingUtilities.invokeLater(thisPanel);
	    } catch (Exception ex) {
		db("Problem changing panels...");
	    }
	}
    }

    private void db(String s) {
	System.err.println(s);
    }
}
