/*
 * Copyright (C) 2000 Free Software Foundation, Inc.
 * Brian Satterfield <legowhore@legowhore.com>, 2000.
 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package com.legowhore.q3;

import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JTextField;
import javax.swing.JLabel;
import javax.swing.JFileChooser;
import javax.swing.JCheckBox;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Color;
import java.io.File;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.awt.Font;


public class ServerStartPanel extends JPanel {

    JTextField directory;
    JLabel dirLabel;

    JTextField configFile;
    JLabel configLabel;

    JButton locateQ3Button;
    JButton locateConfigButton;
    JButton clientButton;
    JButton serverButton;

    JCheckBox privateBox;

    JFileChooser fileChooser;

    Font smallFont;

    boolean privateServer = false;

    //  parent
    Q3ServerKit q3Gui;

    Runtime runtime = Runtime.getRuntime();
    Process process;
    InputStreamReader inputStream;
    BufferedReader bufferedReader;

    //  server process
    ServerProcess server = null;


    public ServerStartPanel(Q3ServerKit q3Gui) {
	this.q3Gui = q3Gui;
	
	setLayout(new PercentLayout());

	smallFont = new Font("plain", Font.PLAIN, 10);
	dirLabel = new JLabel("Q3 Directory:");
	dirLabel.setFont(smallFont);
	dirLabel.setForeground(Color.white);
	directory = new JTextField("/usr/local/games/q3demo");
	directory.setFont(smallFont);
	configLabel = new JLabel("Server config:");
	configLabel.setFont(smallFont);
	configLabel.setForeground(Color.white);
	configFile = new JTextField("server.cfg");
	configFile.setFont(smallFont);
	locateQ3Button = new JButton("locate");
	locateQ3Button.addActionListener(new LocateQ3ButtonListener());
	locateQ3Button.setFont(smallFont);
	locateQ3Button.setBackground(Color.black);
	locateQ3Button.setForeground(Color.white);
	locateConfigButton = new JButton("locate");
	locateConfigButton.setFont(smallFont);
	locateConfigButton.setBackground(Color.black);
	locateConfigButton.setForeground(Color.white);
	locateConfigButton.addActionListener(new LocateServerButtonListener());
	clientButton = new JButton("client");
	clientButton.setFont(smallFont);
	clientButton.setBackground(Color.black);
	clientButton.setForeground(Color.white);
	clientButton.addActionListener(new ClientButtonListener());
	serverButton = new JButton("server");
	serverButton.setFont(smallFont);
	serverButton.setBackground(Color.black);
	serverButton.setForeground(Color.white);
	serverButton.addActionListener(new ServerButtonListener());
	privateBox = new JCheckBox("private server");
	privateBox.setFont(smallFont);
	privateBox.setBackground(Color.black);
	privateBox.setForeground(Color.white);
	privateBox.addActionListener(new PrivateListener());
	add(dirLabel, "0 0 100 5");
	add(directory, "0 7 100 20");
	add(locateQ3Button, "25 22 75 35");

	add(configLabel, "0 38 100 43");
	add(configFile, "0 45 100 58");
	add(locateConfigButton, "25 60 75 73");
	add(privateBox, "25 75 75 85");

	add(clientButton, "0 88 49 100");
	add(serverButton, "51 88 100 100");

	setBackground(Color.black);
    }

    //  this code will be run in the event dispatch thread
    //  used to rescan the maps dir and re-populate the list
    public void run() {

    }

    //  listens for a locate request
    class LocateQ3ButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    String title = ((JButton) e.getSource()).getText();
	    fileChooser = new JFileChooser();
	    fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
	    int returnVal = fileChooser
		.showOpenDialog(ServerStartPanel.this);
	    if (returnVal == JFileChooser.APPROVE_OPTION) {
		File file = fileChooser.getSelectedFile();
		directory.setText(file.getAbsolutePath());
	    }
	}
    }

    //  listens for a locate request
    class LocateServerButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    String title = ((JButton) e.getSource()).getText();
	    fileChooser = new JFileChooser();
	    fileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
	    fileChooser.setFileHidingEnabled(false);
	    int returnVal = fileChooser
		.showOpenDialog(ServerStartPanel.this);
	    if (returnVal == JFileChooser.APPROVE_OPTION) {
		File file = fileChooser.getSelectedFile();
		configFile.setText(file.getName());
	    }
	}
    }

    //  starts the client
    class ClientButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    q3Gui.effectsPanel.setText("Sorry....this feature is "
				       + "not working yet.");
	}
    }

    //  starts a server
    class ServerButtonListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    String dir = directory.getText();
	    String config = configFile.getText();
	    boolean dedicated = privateBox.isSelected();
	    if(server == null)
		server = new ServerProcess(q3Gui);
	    server.startServer(dir, config, dedicated);
	}
    }

    //  starts a server
    class PrivateListener implements ActionListener {
	public void actionPerformed(ActionEvent e) {
	    if(((JCheckBox) e.getSource()).isSelected()) {
		q3Gui.effectsPanel.setText("The server is now private and "
					   + "will not be displayed on the "
					   + "master server...");
		privateServer = true;
	    } else {
		q3Gui.effectsPanel.setText("The server will be displayed "
					   + "on the master server for others"
					   + " to join...");
		privateServer = false;
	    }
	}
    }

    private void db(String s) {
	System.err.println(s);
    }
    
}
