/*
 * Copyright (C) 2000 Free Software Foundation, Inc.
 * Brian Satterfield <legowhore@legowhore.com>, 2000.
 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package com.legowhore.q3;

import javax.swing.JPanel;
import javax.swing.JLabel;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.SwingUtilities;
import java.awt.Font;
import java.awt.Color;
import javax.swing.BorderFactory; 
import javax.swing.border.Border;
import javax.swing.border.TitledBorder;

public class StatisticsPanel extends JPanel implements Runnable {

    Q3ServerKit q3Gui;

    //  different labels
    JLabel uptimeLabel;
    JLabel fragLabel;
    JLabel gamesLabel;
    JLabel connectionsLabel;
    JLabel percentOccupiedLabel;
    
    private Border uptimeBorder;
    private TitledBorder uptimeTitledBorder;

    Font smallFont;

    String uptime = "0 weeks, 0 days [00:00:00]";
    int frags = 0;
    int gamesPlayed = 0;
    int connections = 0;
    double percentOccupied = 0;

    public StatisticsPanel(Q3ServerKit q3Gui) {
	this.q3Gui = q3Gui;
	setLayout(new PercentLayout());
	smallFont = new Font("plain", Font.PLAIN, 10);

	//  different labels
	uptimeLabel = new JLabel(uptime, JLabel.CENTER);
	uptimeLabel.setForeground(Color.white);
	uptimeLabel.setFont(smallFont);
	uptimeBorder = BorderFactory.createLineBorder(Color.white);
	uptimeTitledBorder
	    = BorderFactory.createTitledBorder(uptimeBorder, "uptime");
	uptimeTitledBorder.setTitleColor(Color.red);
	uptimeLabel.setBorder(uptimeTitledBorder);
	add(uptimeLabel, "0 0 100 20");

	fragLabel = new JLabel("" + frags, JLabel.CENTER);
	fragLabel.setForeground(Color.white);
	fragLabel.setFont(smallFont);
	add(fragLabel, "0 21 100 31");

	gamesLabel = new JLabel("" + gamesPlayed, JLabel.CENTER);
	gamesLabel.setForeground(Color.white);
	gamesLabel.setFont(smallFont);
	add(gamesLabel, "0 32 100 42");

	connectionsLabel = new JLabel("" + connections, JLabel.CENTER);
	connectionsLabel.setForeground(Color.white);
	connectionsLabel.setFont(smallFont);
	add(connectionsLabel, "0 43 100 53");

	percentOccupiedLabel = new JLabel("" + percentOccupied + "%", 
					  JLabel.CENTER);
	percentOccupiedLabel.setForeground(Color.white);
	percentOccupiedLabel.setFont(smallFont);
	add(percentOccupiedLabel, "0 54 100 64");
	setBackground(Color.black);
	setForeground(Color.white);
    }

    protected void setUptime(String uptime) {
	this.uptime = uptime;
    }

    protected void setFrags(int frags) {
	this.frags = frags;
    }

    protected void setGamesPlayed(int gamesPlayed) {
	this.gamesPlayed = gamesPlayed;
    }

    protected void setConnections(int connections) {
	this.connections = connections;
    }
    
    protected void setPercentOccupied(double percentOccupied) {
	this.percentOccupied = percentOccupied;
    }

    protected void updatePanel() {
	try {
	    SwingUtilities.invokeLater(this);
	} catch (Exception e) {
	    db("Problem updating statistics...");
	}
    }

    //  run in the event dispatch thread...
    //  used to update the panel
    public void run() {
	uptimeLabel.setText(uptime);
	fragLabel.setText("Total frags: " + frags);
	gamesLabel.setText("Total games: " + gamesPlayed);
	connectionsLabel.setText("Total connections: " + connections);
	String percent = Double.toString(percentOccupied);
	if(percent.indexOf('.') >= 0 && percent.length() > 4)
	    percent = percent.substring(0, percent.indexOf(".") + 2);
	percentOccupiedLabel.setText("Percent Occupied: " + percent + "%");
    }

//     public class TabulateListener implements ActionListener {
// 	public void actionPerformed(ActionEvent e) {
// 	    nextPanel();
// 	}
//     }

    private void db(String s) {
	System.err.println(s);
    }
    
}
